#!/bin/sh

ensureJavaExists() {
  if [ ! -d $JAVA_HOME ]; then
    echo "Please point java.home.jdkXY (ant.properties) to your JDK installation"
    exit 1
  fi
}

setupEnv() {
  ENVIRONMENT="-Dmaven.opts=-U -Djboss.bind.address=$JBOSS_BIND_ADDRESS -Djbossws.integration.target=$JBOSS_TARGET -D$JBOSS_TARGET.home=$JBOSS_INSTANCE"
  export JBOSS_HOME=$JBOSS_INSTANCE
}

stopJBoss() {
  $FRAMEWORK_DIR/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE stop $JBOSS_BIND_ADDRESS
}

startJBoss() {
  $FRAMEWORK_DIR/hudson/jboss/bin/jboss.sh $JBOSS_INSTANCE start $JBOSS_BIND_ADDRESS
}

copyJBossLogs() {
  cp $JBOSS_INSTANCE/server/$JBOSS_CONFIG/log/boot.log $WORKSPACE/jboss-boot.log
  cp $JBOSS_INSTANCE/server/$JBOSS_CONFIG/log/server.log $WORKSPACE/jboss-server.log
}

copyTestLogs() {
  cat $WORKSPACE/tests.log | egrep FIXME\|FAILED | sort -u | tee $WORKSPACE/fixme.txt
  cat $STACK_DIR/modules/testsuite/test-excludes-$JBOSS_TARGET.txt $WORKSPACE/fixme.txt | egrep "\[\S*]" > $WORKSPACE/errata-$JBOSS_TARGET.txt
}

removeJBossLogs() {
  rm -f $JBOSS_INSTANCE/server/$JBOSS_CONFIG/log/boot.log
  rm -f $JBOSS_INSTANCE/server/$JBOSS_CONFIG/log/server.log
}

ensureRunningJBoss() {
  $FRAMEWORK_DIR/hudson/jboss/bin/http-spider.sh $JBOSS_BIND_ADDRESS:8080 $WORKSPACE
  if [ -e $WORKSPACE/spider.failed ]; then
    tail -n 100 $JBOSS_INSTANCE/server/$JBOSS_CONFIG/log/server.log
    stopJBoss
    copyJBossLogs
    exit 1
  fi
}

logMavenDependencies() {
  mvn -Ptestsuite,$JBOSS_TARGET dependency:tree | tee $WORKSPACE/dependency-tree.txt
}

deployCoreDistribution() {
  cd $STACK_DIR
  cp profiles.xml.example profiles.xml
  mvn -Ptestsuite clean
  ant $ENVIRONMENT deploy-$JBOSS_TARGET
}

deployBinaryDistribution() {
  cd $STACK_DIR
  cp profiles.xml.example profiles.xml
  mvn -Ptestsuite clean
  ant $ENVIRONMENT build-bin-dist
  cd target
  rm -rf jbossws-$STACK_ID-bin-dist
  unzip jbossws-$STACK_ID-bin-dist.zip
  cd jbossws-$STACK_ID-bin-dist
  cp ant.properties.example ant.properties
  ant $ENVIRONMENT deploy-$JBOSS_TARGET
}

deploySourceDistribution() {
  cd $STACK_DIR
  cp profiles.xml.example profiles.xml
  mvn -Ptestsuite clean
  ant $ENVIRONMENT build-src-dist
  cd target
  rm -rf jbossws-$STACK_ID-src-dist
  unzip jbossws-$STACK_ID-src-dist.zip
  cd jbossws-$STACK_ID-src-dist
  cp profiles.xml.example profiles.xml
  ant $ENVIRONMENT deploy-$JBOSS_TARGET
}

detectFailures() {
  cat $WORKSPACE/tests.log | egrep "BUILD FAILURE" | tee $WORKSPACE/failure.log
  if [ -s $WORKSPACE/failure.log ]; then
    echo "Failure detected"
    exit 1
  fi
}

runTestsViaMaven() {
  mvn $ENVIRONMENT -Ptestsuite,hudson,$JBOSS_TARGET $TEST_OPTS test 2>&1 | tee $WORKSPACE/tests.log
}

runTestsViaAnt() {
  ant $ENVIRONMENT tests-clean tests $TEST_OPTS 2>&1 | tee $WORKSPACE/tests.log
}

coreTest() {
  setupEnv
  ensureJavaExists
  stopJBoss
  deployCoreDistribution
  removeJBossLogs
  startJBoss
  ensureRunningJBoss
  logMavenDependencies
  runTestsViaMaven
  copyTestLogs
  stopJBoss
  copyJBossLogs
  detectFailures
}

binaryDistributionTest() {
  setupEnv
  ensureJavaExists
  stopJBoss
  deployBinaryDistribution
  removeJBossLogs
  startJBoss
  ensureRunningJBoss
  runTestsViaAnt
  copyTestLogs
  stopJBoss
  copyJBossLogs
  detectFailures
}

sourceDistributionTest() {
  setupEnv
  ensureJavaExists
  stopJBoss
  deploySourceDistribution
  removeJBossLogs
  startJBoss
  ensureRunningJBoss
  logMavenDependencies
  runTestsViaMaven
  copyTestLogs
  stopJBoss
  copyJBossLogs
  detectFailures
}
